@@ -20,7 +20,7 @@ our $VERSION = '1.1.2';
 # @param $args reference to the configuration hash
 sub defaultValuesInit {
     my ( $class, $args ) = splice @_;
-    foreach my $t (qw(https port)) {
+    foreach my $t (qw(https port maintenance)) {
 
         # Skip Handler initialization (values not defined)
         next unless defined $args->{$t};
@@ -117,20 +117,44 @@ sub forgeHeadersInit {
     1;
 }
 
+## @imethod void headerListInit(hashRef args)
+# Lists the exported HTTP headers into $headerList
+# @param $args reference to the configuration hash
+sub headerListInit {
+    my ( $class, $args ) = splice @_;
+
+    foreach my $vhost ( keys %{ $args->{exportedHeaders} } ) {
+        my @tmp = keys %{ $args->{exportedHeaders}->{$vhost} };
+        $headerList->{$vhost} = \@tmp;
+    }
+    1;
+}
+
 ## @rmethod void sendHeaders()
 # Launch function compiled by forgeHeadersInit() for the current virtual host
 sub sendHeaders {
     my $class = shift;
-    my $vhost;
-    $vhost = $apacheRequest->hostname;
+    my $vhost = $apacheRequest->hostname;
     if ( defined( $forgeHeaders->{$vhost} ) ) {
         $class->lmSetHeaderIn( $apacheRequest, &{ $forgeHeaders->{$vhost} } );
     }
 }
 
-## @rmethod protected boolean isProtected()
-# @return True if URI isn't protected (rule "unprotect")
-sub isProtected {
+## @rmethod void cleanHeaders()
+# Unset HTTP headers for the current virtual host, when sendHeaders is skipped
+sub cleanHeaders {
+    my $class = shift;
+    my $vhost = $apacheRequest->hostname;
+    if ( defined( $forgeHeaders->{$vhost} ) ) {
+        $class->lmUnsetHeaderIn( $apacheRequest, @{ $headerList->{$vhost} } );
+    }
+}
+
+## @rmethod protected int isUnprotected()
+# @return 0 if URI is protected,
+# UNPROTECT if it is unprotected by "unprotect",
+# SKIP if is is unprotected by "skip"
+sub isUnprotected {
     my ( $class, $uri ) = splice @_;
     my $vhost = $apacheRequest->hostname;
     for ( my $i = 0 ; $i < $locationCount->{$vhost} ; $i++ ) {
@@ -162,6 +186,24 @@ sub grant {
     return &{ $defaultCondition->{$vhost} }($datas);
 }
 
+## @rmethod protected $ fetchId()
+# Get user cookies and search for Lemonldap::NG cookie.
+# @return Value of the cookie if found, 0 else
+sub fetchId {
+    my $t                 = lmHeaderIn( $apacheRequest, 'Cookie' );
+    my $vhost             = $apacheRequest->hostname;
+    my $lookForHttpCookie = $securedCookie =~ /^(2|3)$/
+      && !( defined( $https->{$vhost} ) ? $https->{$vhost} : $https->{_} );
+    my $value =
+      $lookForHttpCookie
+      ? ( $t =~ /${cookieName}http=([^,; ]+)/o ? $1 : 0 )
+      : ( $t =~ /$cookieName=([^,; ]+)/o ? $1 : 0 );
+
+    $value = $cipher->decryptHex( $value, "http" )
+      if ( $value && $lookForHttpCookie && $securedCookie == 3 );
+    return $value;
+}
+
 ## @cmethod private string _buildUrl(string s)
 # Transform /<s> into http(s?)://<host>:<port>/s
 # @param $s path
@@ -272,6 +314,25 @@ sub transformUri {
     OK;
 }
 
+## @rmethod protected boolean checkMaintenanceMode
+# Check if we are in maintenance mode
+# @return true if maintenance mode
+sub checkMaintenanceMode {
+    my ($class) = splice @_;
+    my $vhost = $apacheRequest->hostname;
+    my $_maintenance =
+      ( defined $maintenance->{$vhost} )
+      ? $maintenance->{$vhost}
+      : $maintenance->{_};
+
+    if ($_maintenance) {
+        $class->lmLog( "Maintenance mode activated", 'debug' );
+        return 1;
+    }
+
+    return 0;
+}
+
 1;
 
 __END__
